==> PPDF_1_1.zip: PubMedPDF/year.php <==
<?php
	include "header.php";
	($xoopsUser) ? $user = $xoopsUser->uname() : $user="guest";
	
	### HOME > Year ###
	if(!@$_GET["journal"]){
		$year = @$_GET["year"];
		
		# navibar
		$name = $year;
		$pass = "year.php~~year=".$year;
		$shortcut = "[<a href=\"javascript:disp('include/paper_desc.php?make_s=y&pass=".$pass."&name=".$name."',500,110)\">Shortcut</a>]";

		echo "<table style=\"width:100%\"><tr><td>";
		echo "<a href=\"index.php\">HOME</a> > ".$year;
		echo "</td><td style=\"text-align:right\">".$shortcut."</td></tr>";
		echo "</table><hr>";
		
		# get year's items
		$sql = "SELECT * FROM ".$T_ID." WHERE Year='".$year."'";
		$res = mysql_query($sql, $conn);
		for($i=0;;$i++){
			if(!$row = mysql_fetch_array($res, MYSQL_ASSOC)) break;
			$journal[$row["Journal"]] ++;
			$item[$i] = $row["PMID"];
		}

		# journal bar
		foreach($journal as $key => $value){
			$sql = "SELECT Journal FROM ".$T_JOURNAL." WHERE id='".$key."'";
			$res = mysql_query($sql, $conn);
			$row = mysql_fetch_array($res, MYSQL_ASSOC);
			$journal2[] = $row["Journal"]."??".$key."??".$value;
		}
		sort($journal2);

		echo "<table><tr>";
		for($i=0; $i<count($journal2); $i++){
			if(!($i % 2)) echo "</tr><tr>";
			$j = explode("??",$journal2[$i]);
			echo "<td><a href=\"year.php?year=".$year."&journal=".$j[1]."\">".$j[0]."</a> (".$j[2].")</td>";
		}
		echo "</tr></table><hr>";
		PAPER_DESCRIPTION($item,$user);

	### HOME > Year > Journal###
	}elseif($journal = @$_GET["journal"]){
	
		$sql = "SELECT Journal FROM ".$T_JOURNAL." WHERE id='".$journal."'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);
		$year = @$_GET["year"];

		# navibar
		$name = $year."_".$row["Journal"];
		if(strlen($name) > 18) $name=substr($name,0,18)."...";
		$pass = "year.php~~year=".$year."^^journal=".$journal;
		$shortcut = "[<a href=\"javascript:disp('include/paper_desc.php?make_s=y&pass=".$pass."&name=".$name."',500,110)\">Shortcut</a>]";

		echo "<table style=\"width:100%\"><tr><td>";
		echo "<a href=\"index.php\">HOME</a> > <a href=\"year.php?year=".$year."\">".$year."</a> > ".$row["Journal"];
		echo "</td><td style=\"text-align:right\">".$shortcut."</td></tr>";
		echo "</table><hr>";
	
		# get year's, journal's items
		$sql = "SELECT * FROM ".$T_ID." WHERE Year='".$year."' AND Journal='".$journal."'";
		$res = mysql_query($sql, $conn);
		for($i=0;;$i++){
			if(!$row = mysql_fetch_array($res, MYSQL_ASSOC)) break;
			$item[$i] = $row["PMID"];
		}
		PAPER_DESCRIPTION($item,$user);
	}

	include (XOOPS_ROOT_PATH."/footer.php");
?>

==> PPDF_1_3.zip: PubMedPDF/year.php <==
<?php
	include "header.php";
	($xoopsUser) ? $user = $xoopsUser->uname() : $user="guest";
	
	### HOME > Year ###
	if(!@$_GET["journal"]){
		$year = @$_GET["year"];
		
		# navibar
		$name = $year;
		$pass = "year.php~~year=".$year;
		$shortcut = "[<a href=\"javascript:disp('include/reg_shortcut.php?make_s=y&pass=".$pass."&name=".$name."',500,110)\">Shortcut</a>]";

		echo "<table style=\"width:100%\"><tr><td>";
		echo "<a href=\"index.php\">HOME</a> > ".$year;
		echo "</td><td style=\"text-align:right\">".$shortcut."</td></tr>";
		echo "</table><hr>";
		
		# get year's items
		$sql = "SELECT * FROM ".$T_ID." WHERE Year='".$year."'";
		$res = mysql_query($sql, $conn);
		for($i=0;;$i++){
			if(!$row = mysql_fetch_array($res, MYSQL_ASSOC)) break;
			$journal[$row["Journal"]] ++;
			$item[$i] = $row["PMID"];
		}

		# journal bar
		foreach($journal as $key => $value){
			$sql = "SELECT Journal,Book FROM ".$T_JOURNAL." WHERE id='".$key."'";
			$res = mysql_query($sql, $conn);
			$row = mysql_fetch_array($res, MYSQL_ASSOC);
			$journal2[] = $row["Journal"]."??".$key."??".$value."??".$row["Book"];
		}
		sort($journal2);

		echo "<table><tr>";
		for($i=0; $i<count($journal2); $i++){
			if(!($i % 2)) echo "</tr><tr>";
			$j = explode("??",$journal2[$i]);

			if(strlen($j[0]) > 18){
				$j[0] = substr($j[0],0,18)."...";
			}

			if($j[3]) $j[0] = "<i>".$j[0]."</i>";
			echo "<td><a href=\"year.php?year=".$year."&journal=".$j[1]."\">".$j[0]."</a> (".$j[2].")</td>";
		}
		echo "</tr></table><hr>";
		PAPER_DESCRIPTION($item,$user,$perm);

	### HOME > Year > Journal###
	}elseif($journal = @$_GET["journal"]){
	
		$sql = "SELECT Journal FROM ".$T_JOURNAL." WHERE id='".$journal."'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);
		$year = @$_GET["year"];

		# navibar
		$name = $year."_".$row["Journal"];
		if(strlen($name) > 18) $name=substr($name,0,18)."...";
		$pass = "year.php~~year=".$year."^^journal=".$journal;
		$shortcut = "[<a href=\"javascript:disp('include/paper_desc.php?make_s=y&pass=".$pass."&name=".$name."',500,110)\">Shortcut</a>]";

		echo "<table style=\"width:100%\"><tr><td>";
		echo "<a href=\"index.php\">HOME</a> > <a href=\"year.php?year=".$year."\">".$year."</a> > ".$row["Journal"];
		echo "</td><td style=\"text-align:right\">".$shortcut."</td></tr>";
		echo "</table><hr>";
	
		# get year's, journal's items
		$sql = "SELECT * FROM ".$T_ID." WHERE Year='".$year."' AND Journal='".$journal."'";
		$res = mysql_query($sql, $conn);
		for($i=0;;$i++){
			if(!$row = mysql_fetch_array($res, MYSQL_ASSOC)) break;
			$item[$i] = $row["PMID"];
		}
		PAPER_DESCRIPTION($item,$user,$perm);
	}

	include (XOOPS_ROOT_PATH."/footer.php");
?>
